disp('Wound Copper Coil Comparison to Elliptic Integral');
disp('Michael Treanor')
disp('treanorm@ieee.org')
disp(' ');
disp('This program consider an axisymmetric magnetostatic problem');
disp('of a single-turn coil, radius 75 mm, diameter 4 mm.  The');
disp('coil has 1 turn and the coil current is 100 Amps. The objective of');
disp('the analysis is to compare the flux density on an arc around ');
disp('the coil to the same values calculated by elliptic integrals');
disp('by plotting the field along an arc. This analysis employs an');
disp('"improvised asymptotic boundary condition" to approximate an');
disp('unbounded solution domain.');
disp(' ');

openfemm;

% We need to create a new Magnetostatics document to work on.

newdocument(0);

% Define the problem type.  Magnetostatic; Units of mm; Axisymmetric; 
% Precision of 10^(-8) for the linear solver; a placeholder of 0 for 
% the depth dimension, and an angle constraint of 30 degrees

mi_probdef(0, 'millimeters', 'axi', 1.e-8, 0, 30);

% draw a circle to represent one turn, for comparison to elliptic integral
x1=73;
x2=77;
y1=0;
y2=y1;
angle=180;
maxseg=30;
mi_drawarc(x1,y1,x2,y2,angle,maxseg)
mi_drawarc(x2,y1,x1,y2,angle,maxseg)

% Add block labels, one to each the coil and air regions.
mi_addblocklabel(75,0);
mi_addblocklabel(30,100);

% Define an "improvised asymptotic boundary condition"
% This will mimic an "open" solution domain
mi_makeABC(7,200,0,0,0);

% Add some materials properties
mi_addmaterial('Air', 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0);
mi_addmaterial('Coil', 1, 1, 0, 0, 58*0.65, 0, 0, 1, 0, 0, 0);

% Add a "circuit property" so that we can calculate the properties of the
% coil as seen from the terminals.
I_0=100;
mi_addcircprop('icoil', I_0, 1);

% Apply the materials to the appropriate block labels
mi_selectlabel(75,0);
mi_setblockprop('Coil', 0, 1, 'icoil', 0, 0, 1);
mi_clearselected

mi_selectlabel(30,100);
mi_setblockprop('Air', 0, 1, '<None>', 0, 0, 0);
mi_clearselected

% Now, the finished input geometry can be displayed.
mi_zoomnatural

% We have to give the geometry a name before we can analyze it.
mi_saveas('coilloop.fem');


% Now,analyze the problem and load the solution when the analysis is finished

mi_analyze
mi_loadsolution

% If we were interested in the flux density at specific positions, 
% we could inquire at specific points directly.  Or we could, for example, 
% plot the results along an arc using Octave's built-in plotting routines:
th=(0:90)*pi/180;
r_c=150;
zee=r_c*sin(th);
arr=r_c*cos(th);
bee=mo_getb(arr,zee);
figure(1);
plot(th*180/pi,bee(:,1),'r')
hold on;
plot(th*180/pi,bee(:,2),'b')
xlabel('Angle (deg)');
ylabel('Flux density, Tesla');
title('Plot of B_r (r) and B_z (b), with elliptic integral calculation, along a 150-mm arc.');
% The program will report the terminal properties of the circuit:
% current, voltage, and flux linkage 

vals = mo_getcircuitproperties('icoil');

% If we were interested in inductance, it could be obtained by
% dividing flux linkage by current

L = vals(3)/vals(1);
disp(sprintf('The self-inductance of the coil is %f uH',L*1e6));
uo=pi*4e-7;
mm=0.001;
a=((x1+x2)/2)*mm;
R=((x2-x1)/2)*mm;
% For analytical but approximate formula for 1-turn inductanc,
% see http://www.thompsonrd.com/induct2.pdf
Lapprox = uo*a*(log(8*a/R)-1.75);
disp(sprintf('Wheeler approx. inductance is %f uH',Lapprox*1e6));

% The following statements determine B by performing an elliptic integral of the current
% Define coil parameters. I_0 was already defined;
for i = 1:91
	[B_rad(i),B_z(i)] = B_ellip(arr(i)/1000,zee(i)/1000,I_0,0,a);
end
plot(th*180/pi,B_rad,'-m')
plot(th*180/pi,B_z,'-c')

% When the analysis is completed, FEMM can be shut down.
closefemm
